MainClassGenerator class

Generator for main localization class

Constructors

MainClassGenerator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateClassAndDelegate(List<LocalizationSheet> sheets, String className, bool includeFlutterDelegates) → String
Generate just the class + delegate bodies — no file header, no imports.
generateContent(List<LocalizationSheet> sheets, String className, bool includeFlutterDelegates) → String
Generate full main class file content as String (CLI mode).
generateMainClass(List<LocalizationSheet> sheets, String outputDir, String className, bool includeFlutterDelegates) → Future<void>
Write main class file to disk (CLI mode).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited