SheetClassGenerator class

Generator for individual sheet localization classes

Constructors

SheetClassGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateClassBody(LocalizationSheet sheet) String
Generate class body only (no file header). Used by builder for inline mode.
generateSheetClass(LocalizationSheet sheet, String outputDir) Future<void>
Generate individual sheet class file
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited