ExcelTranslatorBuilder class
Build runner builder for Excel Translator.
Triggered by pubspec.yaml. Also reruns when the excel/csv/ods file changes because reading it via buildStep registers it as an implicit dependency.
Output directory defaults to lib/generated. To use a custom directory, set output_dir in your build.yaml builder options:
targets: $default: builders: excel_translator|excel_translator: options: output_dir: lib/config/l10n
The output_dir in pubspec.yaml is used by the CLI only. When running via build_runner, the build.yaml options value takes precedence.
Constructors
- ExcelTranslatorBuilder({String outputDir = 'lib/generated'})
Properties
-
buildExtensions
→ Map<
String, List< String> > -
Mapping from input file extension to output file extensions.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildStep buildStep) → Future< void> -
Generates the outputs for a given
BuildStep. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited