LocalizationSheet class
Represents a sheet of localizations with translations and supported languages
Constructors
-
LocalizationSheet({required String name, required List<
Translation> translations, required List<Language> supportedLanguages}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
languageCodes
→ List<
String> -
Get all language codes supported by this sheet
no setter
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedLanguages
→ List<
Language> -
final
-
translations
→ List<
Translation> -
final
Methods
-
copyWith(
{String? name, List< Translation> ? translations, List<Language> ? supportedLanguages}) → LocalizationSheet -
getTranslation(
String key) → Translation? - Get translation by key
-
getValue(
String key, String languageCode) → String? - Get value for specific key and language
-
hasKey(
String key) → bool - Check if sheet contains a specific translation key
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsLanguage(
String languageCode) → bool - Check if sheet supports a specific language
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override